# Functions for manipulating the grid environment
#
# prepare - can be used only by other functions
#                                     - creates a tmp 
#                                     - check whether LCG_ENV_SET is set
#                                     - sets field separator and passes the arguments
# destroy - can be used only by other functions:
#                                     - delete the tmp file and unset unnecessary variables
#
#
# gridpath_prepend - prepend a value to a path-like environmnet variable
#                                     - puts a ':' to the end end the beginning of the variable
#                                     - removes the value from the string and removes duplicate '::'
#                                     - prepend the value to the beginning of the variable
#                                     - removes duplicate '::' and removes ':' from the beginning and the end variable
#                                     - export the variable
#
# gridpath_append - the same as prepend but it appends the value to the end of the variable
# gridenv_delete  - delete a value from an environment variable. if the value becomes null string then it unsets the environment variable
# gridemv_set     - sets an environment variable
# gridenv_setind  - sets an environment variable if it is not already defined



function gridenv_prepare() {
                if ! [ "x${LCG_ENV_SET}" = "x" ] ; then return 1; fi
                mytmpfile=`mktemp /tmp/grid-env.XXXX`
                myfieldsep=":"; myvar="$1" ; myvalue="$2"                
}

function gridenv_destroy() {
                rm -f ${mytmpfile} ; unset mytmpfile;
                unset myvar; unset myvalue; unset myfieldsep;
}

function gridpath_prepend() {
                gridenv_prepare "$1" "$2";
                if [ $? -ne 0 ]; then return 0; fi
                eval   ${myvar}="${myfieldsep}\${${myvar}}${myfieldsep}";                
                eval   echo \${${myvar}} | eval sed -e 's%${myfieldsep}${myvalue}${myfieldsep}%${myfieldsep}%g' \
                                             -e "s%${myfieldsep}\{2,3\}%${myfieldsep}%g"                 \
                                             -e "s%${myfieldsep}\{2,3\}%${myfieldsep}%g" > ${mytmpfile}
                eval   ${myvar}=`cat ${mytmpfile}`;
                eval   ${myvar}="${myvalue}\${${myvar}}"
                eval   echo \${${myvar}} | sed -e "s%${myfieldsep}\{2,3\}%${myfieldsep}%g" -e "s%^${myfieldsep}%%g" -e "s%${myfieldsep}\$%%g" > ${mytmpfile};
                eval   export ${myvar}=`cat $mytmpfile`;
                gridenv_destroy 
}

function gridpath_append() {
                gridenv_prepare "$1" "$2";
                if [ $? -ne 0 ]; then return 0; fi
                eval   ${myvar}="${myfieldsep}\${${myvar}}${myfieldsep}";                
                eval   echo \${${myvar}} | eval sed -e 's%${myfieldsep}${myvalue}${myfieldsep}%${myfieldsep}%g' \
                                             -e "s%${myfieldsep}\{2,3\}%${myfieldsep}%g"                 \
                                             -e "s%${myfieldsep}\{2,3\}%${myfieldsep}%g" > ${mytmpfile}
                eval   ${myvar}=`cat ${mytmpfile}`;
                eval   ${myvar}="\${${myvar}}${myvalue}"
                eval   echo \${${myvar}} | sed -e "s%${myfieldsep}\{2,3\}%${myfieldsep}%g" -e "s%^${myfieldsep}%%g" -e "s%${myfieldsep}\$%%g" > ${mytmpfile};
                eval   export ${myvar}=`cat $mytmpfile`;
                gridenv_destroy 
}

function gridenv_delete() {
                gridenv_prepare "$1" "$2";
                if [ $? -ne 0 ]; then return 0; fi
                eval   ${myvar}="${myfieldsep}\${${myvar}}${myfieldsep}";                
                eval   echo \${${myvar}} | eval sed -e 's%${myfieldsep}${myvalue}${myfieldsep}%${myfieldsep}%g' \
                                             -e "s%${myfieldsep}\{2,3\}%${myfieldsep}%g"                 \
                                             -e "s%${myfieldsep}\{2,3\}%${myfieldsep}%g" > ${mytmpfile}
                eval   ${myvar}=`cat ${mytmpfile}`;
                eval   echo \${${myvar}} | sed -e "s%${myfieldsep}\{2,3\}%${myfieldsep}%g" -e "s%^${myfieldsep}%%g" -e "s%${myfieldsep}\$%%g" > ${mytmpfile};
                eval   export ${myvar}=`cat $mytmpfile`;
                gridenv_destroy 
}

function gridenv_set() {
                gridenv_prepare "$1" "$2";
                if [ $? -ne 0 ]; then return 0; fi
                eval export ${myvar}="\"${myvalue}\""
                gridenv_destroy
}

function gridenv_setind() {
                gridenv_prepare "$1" "$2";
                if [ $? -ne 0 ]; then return 0; fi
                eval export ${myvar}=\${${myvar}:-$myvalue}
                gridenv_destroy 
}

